wlan_bearer/wlanldd/wlan_common/umac_common/inc/UmacDot11Synchronize.h
changeset 39 3d23268b50f6
parent 13 ab7247ff6ef9
--- a/wlan_bearer/wlanldd/wlan_common/umac_common/inc/UmacDot11Synchronize.h	Tue Jul 06 16:24:00 2010 +0300
+++ b/wlan_bearer/wlanldd/wlan_common/umac_common/inc/UmacDot11Synchronize.h	Wed Aug 18 11:35:02 2010 +0300
@@ -16,7 +16,7 @@
 */
 
 /*
-* %version: 19 %
+* %version: 20 %
 */
 
 #ifndef WLANDOT11SYNCHRONIZE_H
@@ -105,8 +105,7 @@
         WlanContextImpl& aCtxImpl, 
         TState aNewState );
 
-    TBool InitActions( 
-        WlanContextImpl& aCtxImpl );
+    TInt InitActions( WlanContextImpl& aCtxImpl ) const;
     
     void SetDot11SlotTime( 
         WlanContextImpl& aCtxImpl );
@@ -209,8 +208,8 @@
     
     TState              iState;
 
-    // true, if the Join operation failed
-    TBool iJoinFailed;
+    /** status of the Join operation */
+    TInt iJoinStatus;
 
 #ifndef NDEBUG
     // max length of state name for tracing